#
# spec file for package perl-Expect
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Expect
Name:           perl-Expect
Version:        1.380.0
Release:        1.1
# 1.38 -> normalize -> 1.380.0
%define cpan_version 1.38
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Automate interactions with command line programs that expose a text term[cut]
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/J/JA/JACOBY/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
Patch0:         Expect.diff
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.64
BuildRequires:  perl(IO::Pty) >= 1.11
BuildRequires:  perl(IO::Tty) >= 1.11
BuildRequires:  perl(Test::More) >= 1.00
Requires:       perl(IO::Pty) >= 1.11
Requires:       perl(IO::Tty) >= 1.11
Provides:       perl(Expect) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
See an explanation of at http://code-maven.com/expect

The Expect module is a successor of Comm.pl and a descendent of Chat.pl. It
more closely resembles the Tcl Expect language than its predecessors. It
does not contain any of the networking code found in Comm.pl. I suspect
this would be obsolete anyway given the advent of IO::Socket and external
tools such as netcat.

Expect.pm is an attempt to have more of a switch() & case feeling to make
decision processing more fluid. Three separate types of debugging have been
implemented to make code production easier.

It is possible to interconnect multiple file handles (and processes) much
like Tcl's Expect. An attempt was made to enable all the features of Tcl's
Expect without forcing Tcl on the victim programmer :-) .

Please, before you consider using Expect, read the FAQs about "I want to
automate password entry for su/ssh/scp/rsh/..." and "I want to use Expect
to automate [anything with a buzzword]..."

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README.md
%license LICENSE

%changelog
* Fri Mar 22 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.38
  see /usr/share/doc/packages/perl-Expect/Changes
  1.38 2024-03-08
  - Fix to fix to timeout code
  1.37 2024-03-07
  - Fix to timeout code
  1.36 2024-02-23
  - Made timeouts optional and added qr// regex support
* Mon Mar  4 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri May 19 2017 coolo@suse.com
- updated to 1.35
  see /usr/share/doc/packages/perl-Expect/Changes
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.32
  see /usr/share/doc/packages/perl-Expect/Changes
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Tue Feb  5 2008 mc@suse.de
- update to version 1.21
  * fix testcase
* Wed Jun 13 2007 mc@suse.de
- remove execute permissions from tutorial files
* Tue Sep 19 2006 mc@suse.de
- Version 1.20
  * fixed non-localized usage of $_
  * added new example ssh.pl
  * added early return to send and send_slow if filehandle was closed
  * fixed bug in expect() param handling (exact pattern "0" was ignored)
  * fixed bug in _make_readable()
* Fri Jul 14 2006 mc@suse.de
- Version 1.18
  - added param check for expect()
  - added another pipe to synchronize spawning. Closing the slave in
    the parent can lead to a hang if the child already wrote
    something into it...
  - some bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Fri Jul 18 2003 mc@suse.de
- add vendorarch changes
- add make test
* Mon May 19 2003 mc@suse.de
- removed unpackaged Files from RPM_BUILD_ROOT
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Fri Apr  5 2002 mc@suse.de
- switch to version 1.15
- changed tests to check out pty behaviour (max. string length)
- added autoflush(1) to log_file
- split 'new' and 'spawn' to be able to set slave pty params via stty
  before actually spawning the program
- added print_log_file(), send() now no longer prints to log file or
  stdout.
- spawn() now uses IO::Pty spawn, thus exec errors are reported and
  ssh should work too!
- timeout handlers now also can exp_continue
- added 'raw_pty' option, also setting master to raw if isatty()
- use 'set_raw' instead of stty("raw"); IO::Stty now optional
- updated docs & FAQs; explained how terminal sizes and SIGWINCH
  should be propagated
- bug fixes
* Wed Nov  7 2001 mc@suse.de
- switch to version 1.12
- exp_Max_Accum didn't work for interact.
- removed soft_close() from DESTROY.  Being overly nice to a doomed process
  doesn't pay off.  Old behaviour is available via
  $Expect::Do_Soft_Close = 1;
- cleanup of log and exp_internal output
- added various aliases for functions starting with 'exp_'
- moved FAQ and intro into the main pod as I got the impression
  that many users didn't bother to read all the documentation
  or didn't know that it was there.
- added a hook for log_file: can be set to a code ref.
* Sun Aug 12 2001 kukuk@suse.de
- Fix path to perl interpreter
* Thu Jun 21 2001 mc@suse.de
- fixed the specfile. Used more RPM macros
* Wed Feb 21 2001 mc@suse.de
- first package, v1.11
